==> tuia-ecb-center-api-1.1.1.63-20211025.144534-3-sources.jar: cn/com/duiba/tuia/ecb/center/happy/dto/HappyClearHomeInfoDto.java <==
package cn.com.duiba.tuia.ecb.center.happy.dto;

import com.google.common.collect.Lists;
import lombok.Getter;
import lombok.Setter;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 * @Description: 苏宁消消乐-首页基础信息
 * @Author: fxr
 * @Date: 2019/8/24
 */

@Getter
@Setter
public class HappyClearHomeInfoDto implements Serializable {
    private static final long serialVersionUID = -4106087545824355385L;

    private Long userId;

    private Integer currentLevel;

    private String nickName;


    /**
     * 财富值
     */
    private Integer wealth;

    /**
     * 总星星数
     */
    private Integer totalStars;

    /**
     * 用户关卡信息
     */
    private List<PersonalLevelInfoDto> levels = Lists.newArrayList();

    /**
     * 剩余道具
     */
    private List<PropDto> remainProp = Lists.newArrayList();


    /**
     * 星星宝箱
     */
    private List<HappyClearStarBoxRecordDTO> starBoxList = Lists.newArrayList();

    /**
     * 剩余体力
     */
    private Integer remainEnargy;

    /**
     * 当日通过分享获取体力次数
     */
    private Long askForEnergy;

    /**
     * 当前可领取宝箱数量
     */
    private Long canReceiveTreasureBoxNum;

    /**
     * 下一关给的碎片数量
     */
    private Integer nextRangeStarsNum;

    /**
     * 用户是否已领取所有的宝箱
     */
    private Boolean isGetAllTreasureBox;

    /**
     * 下一次恢复体力倒计时（秒）
     */
    private Long refectionCountdown;


    private Long redBombSwitchTime;

    private Integer powerConsume;

    private String avatar;

    private Integer currentVideoTimes;

    private Integer totalVideoTimes;

    private Boolean newUser;

    /**
     * 当前抽奖次数
     */
    private Integer currentDrawTimes;

    /**
     * 最大抽奖查次数
     */
    private Integer maxDrawTimes;

    /**
     * 当前红包雨次数
     */
    private Integer currentRainTimes;

    /**
     * 红包雨的最大参与次数
     */
    private Integer maxRainTimes;

    /**
     * 大转盘参互需要的关卡
     */
    private Integer drawNeedLevel;

    /**
     * 红包雨持续时间
     */
    private Integer rainContinueTime;


    /**
     * 礼物
     */
    private HappyClearGiftDTO gift;

    private List<HappyClearMissionDTO> nextDailyMission;

    public static HappyClearHomeInfoDto init(HappyClearExtConfigDTO extConfigDTO, String avatar, String nickName, Boolean isNewUser) {
        HappyClearHomeInfoDto homeInfoDto = new HappyClearHomeInfoDto();
        homeInfoDto.setTotalStars(0);
        homeInfoDto.setLevels(new ArrayList<>());
        homeInfoDto.setRemainProp(new ArrayList<>());
        homeInfoDto.setRemainEnargy(extConfigDTO.getDefaultPower());
        homeInfoDto.setRedBombSwitchTime(0L);
        // homeInfoDto.setPowerConsume(powerConsume);
        homeInfoDto.setAvatar(avatar);
        homeInfoDto.setNickName(nickName);
        homeInfoDto.setCurrentVideoTimes(0);
        homeInfoDto.setTotalVideoTimes(extConfigDTO.getVideoMaxTimes());
        homeInfoDto.setNewUser(isNewUser);
        homeInfoDto.setCurrentDrawTimes(0);
        homeInfoDto.setCurrentRainTimes(0);
        homeInfoDto.setMaxDrawTimes(extConfigDTO.getDrawMaxTimes());
        homeInfoDto.setMaxRainTimes(extConfigDTO.getRainTimes());
        homeInfoDto.setDrawNeedLevel(extConfigDTO.getPassLevelNum());
        homeInfoDto.setRainContinueTime(extConfigDTO.getRainContinueTime() == null ? 10 : extConfigDTO.getRainContinueTime());
        return homeInfoDto;
    }

    private List<HappyClearExchangeItem> shoppingItems;


    private List<HappyClearBillboardAwardInfoDTO> awardInfos;


}

==> tuia-ecb-center-api-1.1.1.65-sources.jar: cn/com/duiba/tuia/ecb/center/happy/dto/HappyClearHomeInfoDto.java <==
package cn.com.duiba.tuia.ecb.center.happy.dto;

import com.google.common.collect.Lists;
import lombok.Getter;
import lombok.Setter;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 * @Description: 苏宁消消乐-首页基础信息
 * @Author: fxr
 * @Date: 2019/8/24
 */

@Getter
@Setter
public class HappyClearHomeInfoDto implements Serializable {
    private static final long serialVersionUID = -4106087545824355385L;

    private Long userId;

    private Integer currentLevel;

    private String nickName;


    /**
     * 财富值
     */
    private Integer wealth;

    /**
     * 总星星数
     */
    private Integer totalStars;

    /**
     * 用户关卡信息
     */
    private List<PersonalLevelInfoDto> levels = Lists.newArrayList();

    /**
     * 剩余道具
     */
    private List<PropDto> remainProp = Lists.newArrayList();


    /**
     * 星星宝箱
     */
    private List<HappyClearStarBoxRecordDTO> starBoxList = Lists.newArrayList();

    /**
     * 剩余体力
     */
    private Integer remainEnargy;

    /**
     * 当日通过分享获取体力次数
     */
    private Long askForEnergy;

    /**
     * 当前可领取宝箱数量
     */
    private Long canReceiveTreasureBoxNum;

    /**
     * 下一关给的碎片数量
     */
    private Integer nextRangeStarsNum;

    /**
     * 用户是否已领取所有的宝箱
     */
    private Boolean isGetAllTreasureBox;

    /**
     * 下一次恢复体力倒计时（秒）
     */
    private Long refectionCountdown;


    private Long redBombSwitchTime;

    private Integer powerConsume;

    private String avatar;

    private Integer currentVideoTimes;

    private Integer totalVideoTimes;

    private Boolean newUser;

    /**
     * 当前抽奖次数
     */
    private Integer currentDrawTimes;

    /**
     * 最大抽奖查次数
     */
    private Integer maxDrawTimes;

    /**
     * 当前红包雨次数
     */
    private Integer currentRainTimes;

    /**
     * 红包雨的最大参与次数
     */
    private Integer maxRainTimes;

    /**
     * 大转盘参互需要的关卡
     */
    private Integer drawNeedLevel;

    /**
     * 红包雨持续时间
     */
    private Integer rainContinueTime;


    /**
     * 礼物
     */
    private HappyClearGiftDTO gift;

    private List<HappyClearMissionDTO> nextDailyMission;

    public static HappyClearHomeInfoDto init(HappyClearExtConfigDTO extConfigDTO, String avatar, Long userId, Boolean isNewUser) {
        HappyClearHomeInfoDto homeInfoDto = new HappyClearHomeInfoDto();
        homeInfoDto.setTotalStars(0);
        homeInfoDto.setLevels(new ArrayList<>());
        homeInfoDto.setRemainProp(new ArrayList<>());
        homeInfoDto.setRemainEnargy(extConfigDTO.getDefaultPower());
        homeInfoDto.setRedBombSwitchTime(0L);
        // homeInfoDto.setPowerConsume(powerConsume);
        homeInfoDto.setAvatar(avatar);
        homeInfoDto.setNickName(userId.toString());
        homeInfoDto.setCurrentVideoTimes(0);
        homeInfoDto.setTotalVideoTimes(extConfigDTO.getVideoMaxTimes());
        homeInfoDto.setNewUser(isNewUser);
        homeInfoDto.setCurrentDrawTimes(0);
        homeInfoDto.setCurrentRainTimes(0);
        homeInfoDto.setMaxDrawTimes(extConfigDTO.getDrawMaxTimes());
        homeInfoDto.setMaxRainTimes(extConfigDTO.getRainTimes());
        homeInfoDto.setDrawNeedLevel(extConfigDTO.getPassLevelNum());
        homeInfoDto.setRainContinueTime(extConfigDTO.getRainContinueTime() == null ? 10 : extConfigDTO.getRainContinueTime());
        homeInfoDto.setUserId(userId);
        return homeInfoDto;
    }

    private List<HappyClearExchangeItem> shoppingItems;


    private List<HappyClearBillboardAwardInfoDTO> awardInfos;


}
